@@ -1,7 +1,7 @@
 context("astyle")
 
 test_that("source code formatting", {
-  skip('not working')
+  skip('run `astyle` test manually')
   skip_on_cran()
   skip_on_os("windows")
   skip_on_travis()
